@@ -19,6 +19,9 @@ library(OECD)
 ## ----dataset-------------------------------------------------------------
 dataset <- "DUR_D"
 
+## ----first_sleep, echo=FALSE---------------------------------------------
+Sys.sleep(5)
+
 ## ----get_data_structure--------------------------------------------------
 dstruc <- get_data_structure(dataset)
 str(dstruc, max.level = 1)
@@ -52,9 +55,11 @@ qplot(data = df_plot, x = obsTime, y = obsValue, color = COUNTRY, geom = "line")
 ## ----browse_metadata, eval=FALSE-----------------------------------------
 #  browse_metadata(dataset)
 
+## ----second_sleep, echo=FALSE--------------------------------------------
+Sys.sleep(5)
+
 ## ----example-------------------------------------------------------------
-df <- get_dataset("PATS_REGION",
-                  filter = "PCT_A.INVENTORS.BEL+BE10.TOTAL+BIOTECH", 
-                  pre_formatted = TRUE)
+df <- get_dataset("REGION_INNOVATION", 
+                  "1+2.BEL+BE1+BE2+BE3+BEZZ.PCT_BIOTECH.ALL+AVG.2013+2014+2015")
 head(df)
 
